#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
#
# A library for access to geocode for address
#
# Copyright (C) 2011 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
#
import sys
import json
from comun import read_from_url
from sun import Sun
import locale
import datetime
locale.setlocale(locale.LC_MESSAGES, '')
LANG = locale.getlocale(locale.LC_MESSAGES)[0].split('_')[0]

'''
import re
import locale
'''
'''
def urlEncodeNonAscii(b):
	language, output_encoding = locale.getdefaultlocale()
	return b.encode(output_encoding or 'utf-8')
'''
ID = '_slN0oHV34Exg09kl5EASmbGBs5y3GJES1N.Oon0wd5Lnh6E5hGdtQmx_MdxpOxKAzftS1dB0yNI_NzTpWaKFXEm'
URLDIR = "http://maps.googleapis.com/maps/api/geocode/json?address=%s&sensor=false"
URLINV = "http://maps.google.com/maps/api/geocode/json?latlng=%s,%s&sensor=false"
URLDIR_YAHOO = 'http://where.yahooapis.com/geocode?q=%s&flags=J&appid=%s'	
URLINV_YAHOO = 'http://where.yahooapis.com/geocode?q=%s,+%s&gflags=R&flags=J&appid=%s'

def s2f(cadena):
	try:
		value = float(cadena)
	except:
		value = 0.0
	return value
	
def get_default_values():
	direction ={}
	direction['street'] = ''
	direction['city'] = ''
	direction['county'] = ''
	direction['state'] = ''
	direction['country'] = ''
	direction['postal_code'] = ''
	direction['search_string'] = ''
	direction['lat'] = 0.0
	direction['lng'] = 0.0
	direction['woeid'] = ''
	direction['alternative'] = ''
	direction['locality'] = ''
	return direction
	
def is_direction_in_directions(direction,directions):
	for adirection in directions:
		if direction['show'] == adirection['show']:
			return True
	return False

def get_directions(search_string):
	if sys.version_info[0] == 3:
		import urllib.parse
		search_string = urllib.parse.quote(search_string)
	else:
		import urllib
		search_string = urllib.quote(search_string)
	url= 'http://api.geonames.org/searchJSON?name_startsWith=%s&style=LONG&lang=%s&username=atareao'%(search_string,LANG)
	response = read_from_url(url)
	if sys.version_info[0] == 3:
		jsonResponse = json.loads(response.decode())
	else:
		jsonResponse = json.loads(response)
	directions = []
	for result in jsonResponse['geonames']:
		direction = {}
		direction['city'] = result['name']
		direction['locality'] = result['name']
		direction['state'] = result['adminName1']
		direction['country'] = result['countryName']
		direction['lng'] = s2f(result['lng'])
		direction['lat'] = s2f(result['lat'])
		direction['show'] = direction['city'] + ' (' + direction['state'] + ') ' +direction['country']
		if not is_direction_in_directions(direction,directions):
			directions.append(direction)
	return directions
	
def get_direction(search_string):
	directions = get_directions(search_string)
	if len(directions)>0:
		return directions[0]
	return None
		
def get_directions2(search_string):
	directions = []
	if sys.version_info[0] == 3:
		import urllib.parse
		search_string = urllib.parse.quote(search_string)
	else:
		import urllib
		search_string = urllib.quote(search_string)	
	print('Searching url: %s'%(URLDIR_YAHOO % (search_string,ID)))
	try:
		yahooResponse = read_from_url(URLDIR_YAHOO % (search_string,ID))
		if sys.version_info[0] == 3:
			jsonResponse = json.loads(yahooResponse.decode())
		else:
			jsonResponse = json.loads(yahooResponse)		
		results = jsonResponse['ResultSet']['Results']
		for ans in results:
			direction = {}
			direction['street'] = ans['street'] if 'street' in ans.keys() else ''
			direction['city'] = ans['city'] if 'city' in ans.keys() else ''
			direction['county'] = ans['county'] if 'county' in ans.keys() else ''
			direction['state'] = ans['state'] if 'state' in ans.keys() else ''
			direction['country'] = ans['country'] if 'country' in ans.keys() else ''
			direction['postal_code'] = ans['uzip'] if 'uzip' in ans.keys() else ''
			direction['search_string'] = direction['city']+','+direction['county']+','+direction['state']+','+direction['country']
			direction['lat'] = s2f(ans['latitude']) if 'latitude' in ans.keys() else 0.0
			direction['lng'] = s2f(ans['longitude']) if 'longitude' in ans.keys() else 0.0
			direction['woeid'] = ans['woeid'] if 'woeid' in ans.keys() else ''
			direction['alternative'] = direction['search_string']
			direction['locality'] = direction['city']
			direction['show'] = direction['city'] + ' ' + direction['state'] + ' ' +direction['country']
			directions.append(direction)
	except Exception as e:
		print('GD %s'%e)
	return directions
	
def get_rawOffset(lat,lon):
	url = 'http://api.geonames.org/timezoneJSON?lat=%s&lng=%s&username=atareao'%(lat,lon)		
	try:
		response = read_from_url(url)
		print(response)
		if sys.version_info[0] == 3:
			jsonResponse = json.loads(response.decode())
		else:
			jsonResponse = json.loads(response)
		#rawOffset = jsonResponse['gmtOffset']
		rawOffset = jsonResponse['rawOffset']
		sunrise = jsonResponse['sunrise']
		year,month,day = sunrise.split(' ')[0].split('-')
		year,month,day = int(year),int(month),int(day)
		h,m=sunrise.split(" ")[1].split(':')
		local_sunrise_time = s2f(h)+s2f(m)/60.0
		asun = Sun()
		utc_sunrise_time, sunset = asun.sunRiseSet(year, month, day, lon, lat)
		rawOffset = float(round(local_sunrise_time-utc_sunrise_time,1))
	except Exception as e:
		print('Timezone Error %s'%e)
		rawOffset = 0.0
	return rawOffset
	
def get_sunrise_sunset(lat,lon):
	url = 'http://api.geonames.org/timezoneJSON?lat=%s&lng=%s&username=atareao'%(lat,lon)	
	try:
		response = read_from_url(url)
		print(response)
		if sys.version_info[0] == 3:
			jsonResponse = json.loads(response.decode())
		else:
			jsonResponse = json.loads(response)		
		sunrise = datetime.datetime.strptime(jsonResponse['sunrise'],'%Y-%m-%d %H:%M')
		sunset = datetime.datetime.strptime(jsonResponse['sunset'],'%Y-%m-%d %H:%M')
	except Exception as e:
		print('Sunrise Sunset error %s'%e)
	return sunrise,sunset
	
def get_inv_directions(lat,lon):
	url = 'http://api.geonames.org/findNearbyPlaceNameJSON?lat=%s&lng=%s&username=atareao'%(lat,lon)	
	directions = []	
	try:
		response = read_from_url(url)
		if sys.version_info[0] == 3:
			jsonResponse = json.loads(response.decode())
		else:
			jsonResponse = json.loads(response)		
		for result in jsonResponse['geonames']:	
			direction = {}
			direction['city'] = result['name']
			direction['locality'] = result['name']
			direction['state'] = result['adminName1']
			direction['country'] = result['countryName']
			direction['lng'] = s2f(result['lng'])
			direction['lat'] = s2f(result['lat'])
			direction['show'] = direction['city'] + ' (' + direction['state'] + ') ' +direction['country']
			directions.append(direction)
	except Exception as e:
		print('GID %s'%e)
	return directions

def get_inv_direction(lat,lon):
	directions = get_inv_directions(lat,lon)
	if len(directions)>0:
		return directions[0]
	return None



def get_inv_direction2(lat,lon):
	direction = get_default_values()	
	try:
		
		URLINV_YAHOO = 'http://query.yahooapis.com/v1/public/yql?q=select * from geo.placefinder where text="%s,%s" and gflags="R"&format=json'
		print('Searching url: %s'%(URLINV_YAHOO % (lat,lon)))
		yahooResponse = read_from_url(URLINV_YAHOO % (lat,lon))
		print(yahooResponse)
		if sys.version_info[0] == 3:
			jsonResponse = json.loads(yahooResponse.decode())
		else:
			jsonResponse = json.loads(yahooResponse)		
		ans = jsonResponse['query']['results']['Result']
		direction['street'] = ans['street']
		direction['city'] = ans['city']
		direction['county'] = ans['county']
		direction['state'] = ans['state']
		direction['country'] = ans['country']
		direction['postal_code'] = ans['uzip']
		direction['search_string'] = ans['city']+','+ans['county']+','+ans['state']+','+ans['country']
		direction['lat'] = s2f(ans['latitude'])
		direction['lng'] = s2f(ans['longitude'])
		direction['woeid'] = ans['woeid']
		direction['alternative'] = direction['search_string']
		direction['locality'] = ans['city']
		if s2f(ans['woeid']) == 0.0:
			direction =  get_direction(direction['search_string'])
	except Exception as e:
		print('GID %s'%e)
		return None
	return direction

if __name__ == "__main__":	
	'''
	import ipaddress
	lat,lon = ipaddress.get_current_location()
	direc = get_inv_direction(lat,lon)
	print(direc)
	direc2 = get_direction('valencia')
	print(direc2)
	print(get_directions2('valencia'))
	'''
	direc3 = get_inv_direction2(39.4697524227712, -0.377386808395386)
	print(direc3)
	#print(get_rawOffset(49, -55))
	print(get_directions('valencia'))
	print(get_direction('Les coves de vinromà, castellón'))
	print(get_directions2('valencia'))
	print(get_rawOffset(28.2109,112.9632))
