#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
#
# A library for access to OpenWeatherMap Weather Service
#
# Copyright (C) 2011 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
import json
import weatherservice
from datetime import datetime
from  weatherservice import WeatherService
from comun import _
from comun import read_from_url



URL_FIND_CITY = 'http://openweathermap.org/data/2.1/find/city?lat=%s&lon=%s&cnt=1'
'''
{"message":"Model=GFS-OWM, ","cod":"200","calctime":0.0205,"cnt":1,"list":[{"id":2519752,"dt":1347083047,"name":"Castello de la Plana","coord":{"lat":39.98,"lon":-0.03},"main":{"temp":293.51,"humidity":48,"pressure":1013,"temp_min":293,"temp_max":294},"wind":{"speed":0,"deg":3},"clouds":{"all":15},"rain":{"3h":0}}]}
'''
URL_CURRENT_CITY = 'http://openweathermap.org/data/2.1/weather/city/%s'#?type=json'
URL_FORECAST_CITY = 'http://openweathermap.org/data/2.1/forecast/city/%s'

CONDITION = {}
CONDITION[200] = 'thunderstorm with light rain'
CONDITION[201] = 'thunderstorm with rain'
CONDITION[202] = 'thunderstorm with heavy rain'
CONDITION[210] = 'light thunderstorm'
CONDITION[211] = 'thunderstorm'
CONDITION[212] = 'heavy thunderstorm'
CONDITION[221] = 'ragged thunderstorm'
CONDITION[230] = 'thunderstorm with light drizzle'
CONDITION[231] = 'thunderstorm with drizzle'
CONDITION[232] = 'thunderstorm with heavy drizzle'
CONDITION[300] = 'light intensity drizzle'
CONDITION[301] = 'drizzle'
CONDITION[302] = 'heavy intensity drizzle'
CONDITION[310] = 'light intensity drizzle rain'
CONDITION[311] = 'drizzle rain'
CONDITION[312] = 'heavy intensity drizzle rain'
CONDITION[321] = 'shower drizzle'
CONDITION[500] = 'light rain'
CONDITION[501] = 'moderate rain'
CONDITION[502] = 'heavy intensity rain'
CONDITION[503] = 'very heavy rain'
CONDITION[504] = 'extreme rain'
CONDITION[511] = 'freezing rain'
CONDITION[520] = 'light intensity shower rain'
CONDITION[521] = 'shower rain'
CONDITION[522] = 'heavy intensity shower rain'
CONDITION[600] = 'light snow'
CONDITION[601] = 'snow'
CONDITION[602] = 'heavy snow'
CONDITION[611] = 'sleet'
CONDITION[621] = 'shower snow'
CONDITION[701] = 'mist'
CONDITION[711] = 'smoke'
CONDITION[721] = 'haze'
CONDITION[731] = 'sand'
CONDITION[741] = 'fog'
CONDITION[800] = 'clear'#sky is clear
CONDITION[801] = 'partly sunny'#few clouds
CONDITION[802] = 'partly cloudy'#scattered clouds
CONDITION[803] = 'cloudy'#broken clouds
CONDITION[804] = 'overcast'#overcast clouds
CONDITION[900] = 'tornado'
CONDITION[901] = 'tropical storm'
CONDITION[902] = 'hurricane'
CONDITION[903] = 'cold'
CONDITION[904] = 'hot'
CONDITION[905] = 'windy'
CONDITION[906] = 'hail'

def find_city(longitude,latitude):
		json_string = read_from_url(URL_FIND_CITY%(latitude,longitude))
		parsed_json = json.loads(json_string.decode())
		elist = parsed_json['list']
		if len(elist)>0:
			return elist[0]['id']
		return None
def fa2f(temperature):
	return (temperature - 273.15)*9.0/5.0+32.0

class OWMWeatherService(WeatherService):
	def __init__(self,longitude=-0.418, latitude=39.360, units = weatherservice.Units()):
		WeatherService.__init__(self,longitude,latitude,units)
		self.id = find_city(longitude,latitude)
		
	def get_weather(self):
		weather_data = self.get_default_values()
		print('OpenWeatherMap Weather Service url:%s'%(URL_CURRENT_CITY%self.id))
		#try:
		if self.id:
			json_string = read_from_url(URL_CURRENT_CITY%self.id)				
			parsed_json = json.loads(json_string.decode())
			if parsed_json['weather'][0]['id'] not in CONDITION.keys():
				condition = 'not available'
			else:
				condition = CONDITION[parsed_json['weather'][0]['id']]
			temperature = fa2f(parsed_json['main']['temp'])
			pressure = parsed_json['main']['pressure'] if 'pressure' in parsed_json['main'] else 0
			humidity = parsed_json['main']['humidity'] if 'humidity' in parsed_json['main'] else 0
			velocity = parsed_json['wind']['speed']
			cloudiness = parsed_json['clouds']['all']
			if 'deg' in  parsed_json['wind'].keys():
				direction = parsed_json['wind']['deg']
			else:
				direction = 0
			wind_direction = weatherservice.degToCompass2(direction)
			weather_data['current_conditions']['condition'] = condition
			weather_data['current_conditions']['condition_text'] = weatherservice.get_condition(condition,'text')
			if weatherservice.is_day_now(weather_data['current_conditions']['sunrise_time'],weather_data['current_conditions']['sunset_time']):
				weather_data['current_conditions']['condition_image'] = weatherservice.get_condition(condition,'image')
				weather_data['current_conditions']['condition_icon_dark'] = weatherservice.get_condition(condition,'icon-dark')
				weather_data['current_conditions']['condition_icon_light'] = weatherservice.get_condition(condition,'icon-light')
			else:
				weather_data['current_conditions']['condition_image'] = weatherservice.get_condition(condition,'image-night')
				weather_data['current_conditions']['condition_icon_dark'] = weatherservice.get_condition(condition,'icon-night-dark')
				weather_data['current_conditions']['condition_icon_light'] = weatherservice.get_condition(condition,'icon-night-light')
			weather_data['current_conditions']['temperature'] = weatherservice.change_temperature(temperature,self.units.temperature)
			weather_data['current_conditions']['pressure'] = weatherservice.change_pressure(pressure,self.units.pressure)
			weather_data['current_conditions']['humidity'] = '%s %%'%(humidity)
			weather_data['current_conditions']['dew_point'] = weatherservice.get_dew_point(humidity,temperature,self.units.temperature)
			weather_data['current_conditions']['wind_condition'] = weatherservice.get_wind_condition2(velocity,wind_direction[0],self.units.wind)
			weather_data['current_conditions']['wind_icon'] = wind_direction[2]
			weather_data['current_conditions']['heat_index'] = weatherservice.get_heat_index(temperature,humidity)
			weather_data['current_conditions']['windchill'] = weatherservice.get_wind_chill(temperature,velocity)
			weather_data['current_conditions']['feels_like'] = weatherservice.get_feels_like(temperature,humidity,velocity,self.units.temperature)
			weather_data['current_conditions']['visibility'] = None
			weather_data['current_conditions']['cloudiness'] = '%s %%'%(cloudiness)
			weather_data['current_conditions']['solarradiation'] = None
			weather_data['current_conditions']['UV'] = None
			weather_data['current_conditions']['precip_1hr'] = None
			weather_data['current_conditions']['precip_today'] = None			
			#
			print('OWMWeatherService url:%s'%(URL_FORECAST_CITY%self.id))
			try:
				json_string = read_from_url(URL_FORECAST_CITY%self.id)
				parsed_json = json.loads(json_string.decode())
				contador = 0
				for i,data in enumerate(parsed_json['list']):
					if str(datetime.fromtimestamp(data['dt'])).find('12:00:00')>-1 and contador < 5:
						condition = CONDITION[data['weather'][0]['id']]
						temperature = fa2f(data['main']['temp'])
						cloudiness = data['clouds']['all']
						pressure = data['main']['pressure']
						humidity = data['main']['humidity']
						velocity = data['wind']['speed']
						t1 = fa2f(data['main']['temp_min'])
						t2 = fa2f(data['main']['temp_max'])
						if 'deg' in  data['wind'].keys():
							direction = data['wind']['deg']
						else:
							direction = 0
						if t1<t2:
							temp_min=str(t1)
							temp_max=str(t2)
						else:
							temp_min=str(t2)
							temp_max=str(t1)							
						wind_direction = weatherservice.degToCompass2(direction)					
						weather_data['forecasts'][contador]['condition'] = condition
						weather_data['forecasts'][contador]['condition_text'] = weatherservice.get_condition(condition,'text')
						weather_data['forecasts'][contador]['condition_image'] = weatherservice.get_condition(condition,'image')
						weather_data['forecasts'][contador]['condition_icon'] = weatherservice.get_condition(condition,'icon-light')																	
						weather_data['forecasts'][contador]['low'] = weatherservice.change_temperature(temp_min,self.units.temperature)
						weather_data['forecasts'][contador]['high'] = weatherservice.change_temperature(temp_max,self.units.temperature)
						weather_data['forecasts'][contador]['cloudiness'] = '%s %%'%(cloudiness)
						weather_data['forecasts'][contador]['avehumidity'] = '%s %%'%(humidity)
						weather_data['forecasts'][contador]['avewind'] = weatherservice.get_wind_condition2(velocity,wind_direction[0],self.units.wind)
						weather_data['forecasts'][contador]['wind_icon'] = wind_direction[2]
						weather_data['forecasts'][contador]['qpf_allday'] = None
						weather_data['forecasts'][contador]['qpf_day'] = None
						weather_data['forecasts'][contador]['qpf_night'] = None
						weather_data['forecasts'][contador]['snow_allday'] = None
						weather_data['forecasts'][contador]['snow_day'] = None
						weather_data['forecasts'][contador]['snow_night'] = None
						weather_data['forecasts'][contador]['maxwind'] = None
						weather_data['forecasts'][contador]['maxhumidity'] = None
						weather_data['forecasts'][contador]['minhumidity'] = None					
						contador += 1
			except Exception as e:
				print(e)
		return weather_data

if __name__ == "__main__":
	longitude=-0.418
	latitude=39.360
	#latitude = 42.98
	#longitude = -81.23
	print(find_city(longitude,latitude))
	owm = OWMWeatherService(longitude=longitude,latitude=latitude)	
	print(owm.get_weather())
